==> ws-v3.50.4-src.tar.gz: ws-v3.50-4/src/sheet/Japanese-sjis.cpp <==
  WSGIappLocaleSet()->setLocaleString("SJIS","","");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Row Counter", "s");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Column Counter", "");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Row Counter", "Œs");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Column Counter","Œ");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Grid Line Type","ObhC̎");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Cell Default Width","Z̕iKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Cell Default Height","σZ̍iKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Height","ŒZ̍iKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Cell Default Font No.","σZ̃tHgiKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Default Font No.","ŒZ̃tHg");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Edit Enabled", "ҏW");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Horizontal number drawing","Z̗ԍ\x95\\");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Vertical number drawing","Z̍sԍ\x95\\");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Sheet Back Color","V[g̔wiF");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Cell Default Back Color","σZ̔wiFiKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Cell Default Text Color","σZ̕FiKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Back Color","ŒZ̔wiF");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Text Color","ŒZ̕F");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Grid Color","Obh̐F");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Select Item","f[^x[X");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort Item1","\x83\\[gڂP");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort1","\x83\\[gP");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort Item2","\x83\\[gڂQ");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort2","\x83\\[gQ");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort Item3","\x83\\[gڂR");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort3","\x83\\[gR");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Select SQL","SQL");
  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR ASC","");
  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR DESC","~");

  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR None","Ȃ");
  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR Horz","");
  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR Vert","");
  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR Both","");

==> ws-v3.80.3-src.tar.gz: ws-v3.80-3/src/sheet/Japanese-sjis.cpp <==
  WSGIappLocaleSet()->setLocaleString("SJIS","","");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Row Counter", "s");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Column Counter", "");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Row Counter", "Œs");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Column Counter","Œ");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Grid Line Type","ObhC̎");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Cell Default Width","Z̕iKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Cell Default Height","σZ̍iKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Height","ŒZ̍iKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Cell Default Font No.","σZ̃tHgiKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Default Font No.","ŒZ̃tHg");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Edit Enabled", "ҏW");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Horizontal number drawing","Z̗ԍ\x95\\");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Vertical number drawing","Z̍sԍ\x95\\");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Sheet Back Color","V[g̔wiF");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Cell Default Back Color","σZ̔wiFiKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Cell Default Text Color","σZ̕FiKlj");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Back Color","ŒZ̔wiF");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Fixed Cell Text Color","ŒZ̕F");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR Grid Color","Obh̐F");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Select Item","f[^x[X");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort Item1","\x83\\[gڂP");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort1","\x83\\[gP");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort Item2","\x83\\[gڂQ");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort2","\x83\\[gQ");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort Item3","\x83\\[gڂR");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Sort3","\x83\\[gR");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Select SQL","SQL");
  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR ASC","");
  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR DESC","~");

  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR None","Ȃ");
  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR Horz","");
  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR Vert","");
  WSGIappLocaleSet()->setLocaleString("SJIS","X:WSSTR Both","");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Cell Auto Resize","f[^x[XڑɃZ̎");
  WSGIappLocaleSet()->setLocaleString("SJIS","p1:WSSTR DB Cell Title","f[^x[XڑɃZ̃^Cg\x95\\");
